==> rivendell-2.18.0.tar.gz: rivendell-2.18.0/rdlogin/rdlogin_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation>RDLogin - Station:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation>rdlogin :</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation>Kann nicht verbinden</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Derzeitiger Nutzer: unbekannt</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>Ben&amp;utzername:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Paßwort:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>Benutzer &amp;Setzen</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>Stan&amp;dardbenutzer</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation>Derzeitiger Benutzer:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Ungültiges Paßwort!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-3.6.4.tar.gz: rivendell-3.6.4/rdlogin/rdlogin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation type="obsolete">RDLogin - Station:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation type="obsolete">rdlogin :</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Kann nicht verbinden</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Derzeitiger Nutzer: unbekannt</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>Ben&amp;utzername:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Paßwort:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>Benutzer &amp;Setzen</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>Stan&amp;dardbenutzer</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Abbre&amp;chen</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation type="obsolete">Derzeitiger Benutzer:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Ungültiges Paßwort!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
